# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

import unittest

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.core import Request
from gvm.protocols.gmp.requests.v226 import ResourceNames, ResourceType


class ResourceNamesTestCase(unittest.TestCase):
    def test_get_resource_names(self) -> None:
        request = ResourceNames.get_resource_names(ResourceType.ALERT)

        self.assertIsInstance(request, Request)

        self.assertEqual(bytes(request), b'<get_resource_names type="ALERT"/>')

        request = ResourceNames.get_resource_names(ResourceType.CERT_BUND_ADV)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="CERT_BUND_ADV"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.CONFIG)

        self.assertEqual(bytes(request), b'<get_resource_names type="CONFIG"/>')

        request = ResourceNames.get_resource_names(
            resource_type=ResourceType.CPE
        )

        self.assertEqual(bytes(request), b'<get_resource_names type="CPE"/>')

        request = ResourceNames.get_resource_names(ResourceType.CREDENTIAL)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="CREDENTIAL"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.CVE)

        self.assertEqual(bytes(request), b'<get_resource_names type="CVE"/>')

        request = ResourceNames.get_resource_names(ResourceType.DFN_CERT_ADV)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="DFN_CERT_ADV"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.FILTER)

        self.assertEqual(bytes(request), b'<get_resource_names type="FILTER"/>')

        request = ResourceNames.get_resource_names(ResourceType.GROUP)

        self.assertEqual(bytes(request), b'<get_resource_names type="GROUP"/>')

        request = ResourceNames.get_resource_names(ResourceType.HOST)

        self.assertEqual(bytes(request), b'<get_resource_names type="HOST"/>')

        request = ResourceNames.get_resource_names(ResourceType.NOTE)

        self.assertEqual(bytes(request), b'<get_resource_names type="NOTE"/>')

        request = ResourceNames.get_resource_names(ResourceType.NVT)

        self.assertEqual(bytes(request), b'<get_resource_names type="NVT"/>')

        request = ResourceNames.get_resource_names(ResourceType.OS)

        self.assertEqual(bytes(request), b'<get_resource_names type="OS"/>')

        request = ResourceNames.get_resource_names(ResourceType.OVERRIDE)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="OVERRIDE"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.PERMISSION)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="PERMISSION"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.PORT_LIST)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="PORT_LIST"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.REPORT_FORMAT)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="REPORT_FORMAT"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.REPORT)

        self.assertEqual(bytes(request), b'<get_resource_names type="REPORT"/>')

        request = ResourceNames.get_resource_names(ResourceType.REPORT_CONFIG)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="REPORT_CONFIG"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.RESULT)

        self.assertEqual(bytes(request), b'<get_resource_names type="RESULT"/>')

        request = ResourceNames.get_resource_names(ResourceType.ROLE)

        self.assertEqual(bytes(request), b'<get_resource_names type="ROLE"/>')

        request = ResourceNames.get_resource_names(ResourceType.SCANNER)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="SCANNER"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.SCHEDULE)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="SCHEDULE"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.TARGET)

        self.assertEqual(bytes(request), b'<get_resource_names type="TARGET"/>')

        request = ResourceNames.get_resource_names(ResourceType.TASK)

        self.assertEqual(bytes(request), b'<get_resource_names type="TASK"/>')

        request = ResourceNames.get_resource_names(ResourceType.TLS_CERTIFICATE)

        self.assertEqual(
            bytes(request), b'<get_resource_names type="TLS_CERTIFICATE"/>'
        )

        request = ResourceNames.get_resource_names(ResourceType.USER)

        self.assertEqual(bytes(request), b'<get_resource_names type="USER"/>')

    def test_get_resource_names_missing_resource_type(self) -> None:
        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_names(resource_type=None)  # type: ignore

        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_names(resource_type="")

        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_names("")

    def test_get_resource_names_invalid_resource_type(self) -> None:
        with self.assertRaises(InvalidArgument):
            ResourceNames.get_resource_names(resource_type="foo")

    def test_get_resource_names_with_filter_string(self) -> None:
        request = ResourceNames.get_resource_names(
            ResourceType.CPE, filter_string="foo=bar"
        )

        self.assertEqual(
            bytes(request), b'<get_resource_names type="CPE" filter="foo=bar"/>'
        )

    def test_get_resource_name(self):
        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.ALERT, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="ALERT"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.CERT_BUND_ADV, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="CERT_BUND_ADV"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.CONFIG, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="CONFIG"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.CPE, resource_id="i1"
        )

        self.assertEqual(
            bytes(request), b'<get_resource_names resource_id="i1" type="CPE"/>'
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.CREDENTIAL, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="CREDENTIAL"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.CVE, resource_id="i1"
        )

        self.assertEqual(
            bytes(request), b'<get_resource_names resource_id="i1" type="CVE"/>'
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.DFN_CERT_ADV, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="DFN_CERT_ADV"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.FILTER, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="FILTER"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.GROUP, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="GROUP"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.HOST, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="HOST"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.NOTE, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="NOTE"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.NVT, resource_id="i1"
        )

        self.assertEqual(
            bytes(request), b'<get_resource_names resource_id="i1" type="NVT"/>'
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.OS, resource_id="i1"
        )

        self.assertEqual(
            bytes(request), b'<get_resource_names resource_id="i1" type="OS"/>'
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.PERMISSION, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="PERMISSION"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.PORT_LIST, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="PORT_LIST"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.REPORT_FORMAT, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="REPORT_FORMAT"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.REPORT, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="REPORT"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.REPORT_CONFIG, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="REPORT_CONFIG"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.RESULT, resource_id="i1"
        )
        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="RESULT"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.ROLE, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="ROLE"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.SCANNER, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="SCANNER"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.SCHEDULE, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="SCHEDULE"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.TARGET, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="TARGET"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.TASK, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="TASK"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.TLS_CERTIFICATE, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="TLS_CERTIFICATE"/>',
        )

        request = ResourceNames.get_resource_name(
            resource_type=ResourceType.USER, resource_id="i1"
        )

        self.assertEqual(
            bytes(request),
            b'<get_resource_names resource_id="i1" type="USER"/>',
        )

    def test_get_resource_name_missing_resource_type(self):
        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_name(
                resource_id="i1", resource_type=None
            )

        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_name(resource_id="i1", resource_type="")

        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_name("i1", "")

    def test_get_resource_name_invalid_resource_type(self):
        with self.assertRaises(InvalidArgument):
            ResourceNames.get_resource_name(
                resource_id="i1", resource_type="foo"
            )

    def test_get_resource_name_missing_resource_id(self):
        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_name(
                resource_id="", resource_type=ResourceType.CPE
            )

        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_name("", resource_type=ResourceType.CPE)

        with self.assertRaises(RequiredArgument):
            ResourceNames.get_resource_name(
                resource_id=None, resource_type=ResourceType.CPE
            )



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import GvmError


class GmpDeleteHostTestMixin:
    def test_delete_host(self):
        self.gmp.delete_host(host_id="a1")

        self.connection.send.has_been_called_with(
            b'<delete_asset asset_id="a1"/>'
        )

    def test_missing_arguments(self):
        with self.assertRaises(GvmError):
            self.gmp.delete_host(None)



# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224 import Gmpv224TestCase
from .schedules import (
    GmpCloneScheduleTestMixin,
    GmpCreateScheduleTestMixin,
    GmpDeleteScheduleTestMixin,
    GmpGetSchedulesTestMixin,
    GmpGetScheduleTestMixin,
    GmpModifyScheduleTestMixin,
)


class Gmpv224DeleteScheduleTestCase(
    GmpDeleteScheduleTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224GetScheduleTestCase(GmpGetScheduleTestMixin, Gmpv224TestCase):
    pass


class Gmpv224GetSchedulesTestCase(GmpGetSchedulesTestMixin, Gmpv224TestCase):
    pass


class Gmpv224CloneScheduleTestCase(GmpCloneScheduleTestMixin, Gmpv224TestCase):
    pass


class Gmpv224CreateScheduleTestCase(
    GmpCreateScheduleTestMixin, Gmpv224TestCase
):
    pass


class Gmpv224ModifyScheduleTestCase(
    GmpModifyScheduleTestMixin, Gmpv224TestCase
):
    pass



# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.entities.audits import (
    GmpCloneAuditTestMixin,
    GmpCreateAuditTestMixin,
    GmpDeleteAuditTestMixin,
    GmpGetAuditsTestMixin,
    GmpGetAuditTestMixin,
    GmpModifyAuditTestMixin,
    GmpResumeAuditTestMixin,
    GmpStartAuditTestMixin,
    GmpStopAuditTestMixin,
)
from ...gmpv225 import GMPTestCase


class Gmpv225CloneAuditTestCase(GmpCloneAuditTestMixin, GMPTestCase):
    pass


class Gmpv225CreateAuditTestCase(GmpCreateAuditTestMixin, GMPTestCase):
    pass


class Gmpv225DeleteAuditTestCase(GmpDeleteAuditTestMixin, GMPTestCase):
    pass


class Gmpv225GetAuditTestCase(GmpGetAuditTestMixin, GMPTestCase):
    pass


class Gmpv225GetAuditsTestCase(GmpGetAuditsTestMixin, GMPTestCase):
    pass


class Gmpv225ModifyAuditTestCase(GmpModifyAuditTestMixin, GMPTestCase):
    pass


class Gmpv225ResumeAuditTestCase(GmpResumeAuditTestMixin, GMPTestCase):
    pass


class Gmpv225StartAuditTestCase(GmpStartAuditTestMixin, GMPTestCase):
    pass


class Gmpv225StopAuditTestCase(GmpStopAuditTestMixin, GMPTestCase):
    pass



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#


class GmpGetRolesTestMixin:
    def test_get_roles(self):
        self.gmp.get_roles()

        self.connection.send.has_been_called_with(b"<get_roles/>")

    def test_get_roles_with_filter_string(self):
        self.gmp.get_roles(filter_string="foo=bar")

        self.connection.send.has_been_called_with(
            b'<get_roles filter="foo=bar"/>'
        )

    def test_get_roles_with_filter_id(self):
        self.gmp.get_roles(filter_id="f1")

        self.connection.send.has_been_called_with(b'<get_roles filt_id="f1"/>')

    def test_get_roles_with_trash(self):
        self.gmp.get_roles(trash=True)

        self.connection.send.has_been_called_with(b'<get_roles trash="1"/>')

        self.gmp.get_roles(trash=False)

        self.connection.send.has_been_called_with(b'<get_roles trash="0"/>')



# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.entities.reports import (
    GmpDeleteReportTestMixin,
    GmpGetReportsTestMixin,
    GmpGetReportTestMixin,
    GmpImportReportTestMixin,
)
from ...gmpv225 import GMPTestCase


class Gmpv225DeleteReportTestCase(GmpDeleteReportTestMixin, GMPTestCase):
    pass


class Gmpv225GetReportTestCase(GmpGetReportTestMixin, GMPTestCase):
    pass


class Gmpv225GetReportsTestCase(GmpGetReportsTestMixin, GMPTestCase):
    pass


class Gmpv225ImportReportTestCase(GmpImportReportTestMixin, GMPTestCase):
    pass



# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""
API wrapper for retrieving metadata from the openvasd HTTP API using HEAD requests.
"""

from dataclasses import dataclass

import httpx

from ._api import OpenvasdAPI


@dataclass
class Metadata:
    """
    Represents metadata returned by the openvasd API.

    Attributes:
        api_version: Comma separated list of available API versions
        feed_version: Version of the feed.
        authentication: Supported authentication methods
    """

    api_version: str
    feed_version: str
    authentication: str


@dataclass
class MetadataError:
    """
    Represents an error response from the metadata API.

    Attributes:
        error: Error message.
        status_code: HTTP status code of the error response.
    """

    error: str
    status_code: int


class MetadataAPI(OpenvasdAPI):
    """
    Provides access to metadata endpoints exposed by the openvasd server
    using lightweight HTTP HEAD requests.

    These endpoints return useful information in HTTP headers such as:
    - API version
    - Feed version
    - Authentication type

    If the scanner is protected and the request is unauthorized, a 401 response
    is handled gracefully.
    """

    def get(self) -> Metadata | MetadataError:
        """
        Perform a HEAD request to `/` to retrieve top-level API metadata.

        Returns:
            A Metadata instance or MetadataError if exceptions are suppressed and an error occurs.

        Raises:
            httpx.HTTPStatusError: For non-401 HTTP errors if exceptions are not suppressed.

        See: HEAD / in the openvasd API documentation.
        """
        try:
            response = self._client.head("/")
            response.raise_for_status()
            return Metadata(
                api_version=response.headers.get("api-version"),
                feed_version=response.headers.get("feed-version"),
                authentication=response.headers.get("authentication"),
            )
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return MetadataError(
                    error=str(e), status_code=e.response.status_code
                )
            raise

    def get_scans(self) -> Metadata | MetadataError:
        """
        Perform a HEAD request to `/scans` to retrieve scan endpoint metadata.

        Returns:
            A Metadata instance or MetadataError if exceptions are suppressed and an error occurs.

         Raises:
             httpx.HTTPStatusError: For non-401 HTTP errors if exceptions are not suppressed.

         See: HEAD /scans in the openvasd API documentation.
        """
        try:
            response = self._client.head("/scans")
            response.raise_for_status()
            return Metadata(
                api_version=response.headers.get("api-version"),
                feed_version=response.headers.get("feed-version"),
                authentication=response.headers.get("authentication"),
            )
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return MetadataError(
                    error=str(e), status_code=e.response.status_code
                )
            raise



# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from .test_delete_report import GmpDeleteReportTestMixin
from .test_get_report import GmpGetReportTestMixin
from .test_get_reports import GmpGetReportsTestMixin
from .test_import_report import GmpImportReportTestMixin

__all__ = (
    "GmpDeleteReportTestMixin",
    "GmpGetReportTestMixin",
    "GmpGetReportsTestMixin",
    "GmpImportReportTestMixin",
)



# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""
Greenbone Management Protocol (GMP) version 22.6
"""

from collections.abc import Sequence

from .._protocol import T
from ._gmp225 import GMPv225
from .requests.v226 import (
    AuditReports,
    EntityID,
    Filters,
    FilterType,
    ReportConfigParameter,
    ReportConfigs,
    ReportFormatType,
    Reports,
    ResourceNames,
    ResourceType,
)


class GMPv226(GMPv225[T]):
    """
    A class implementing the Greenbone Management Protocol (GMP) version 22.6

    Example:

        .. code-block:: python

            from gvm.protocols.gmp import GMPv226 as GMP

            with GMP(connection) as gmp:
                resp = gmp.get_tasks()
    """

    @staticmethod
    def get_protocol_version() -> tuple[int, int]:
        return (22, 6)

    def get_resource_names(
        self,
        resource_type: ResourceType,  # type: ignore[override]
        *,
        filter_string: str | None = None,
    ) -> T:
        """Request a list of resource names and IDs

        Arguments:
            resource_type: Type must be either ALERT, CERT_BUND_ADV,
                CONFIG, CPE, CREDENTIAL, CVE, DFN_CERT_ADV, FILTER,
                GROUP, HOST, NOTE, NVT, OS, OVERRIDE, PERMISSION,
                PORT_LIST, REPORT_FORMAT, REPORT, REPORT_CONFIG, RESULT, ROLE,
                SCANNER, SCHEDULE, TARGET, TASK, TLS_CERTIFICATE
                or USER
            filter_string: Filter term to use for the query
        """
        return self._send_request_and_transform_response(
            ResourceNames.get_resource_names(
                resource_type, filter_string=filter_string
            )
        )

    def get_resource_name(
        self,
        resource_id: str,
        resource_type: ResourceType,  # type: ignore[override]
    ) -> T:
        """Request a single resource name

        Arguments:
            resource_id: ID of an existing resource
            resource_type: Type must be either ALERT, CERT_BUND_ADV,
                CONFIG, CPE, CREDENTIAL, CVE, DFN_CERT_ADV, FILTER,
                GROUP, HOST, NOTE, NVT, OS, OVERRIDE, PERMISSION,
                PORT_LIST, REPORT_FORMAT, REPORT, REPORT_CONFIG, RESULT, ROLE,
                SCANNER, SCHEDULE, TARGET, TASK, TLS_CERTIFICATE
                or USER
        """
        return self._send_request_and_transform_response(
            ResourceNames.get_resource_name(resource_id, resource_type)
        )

    def delete_report(self, report_id: EntityID) -> T:
        """Deletes an existing scan report

        Args:
            report_id: UUID of the report to be deleted.
        """
        return self._send_request_and_transform_response(
            Reports.delete_report(report_id)
        )

    def get_report(
        self,
        report_id: EntityID,
        *,
        filter_string: str | None = None,
        filter_id: str | None = None,
        delta_report_id: EntityID | None = None,
        report_format_id: str | ReportFormatType | None = None,
        report_config_id: str | None = None,
        ignore_pagination: bool | None = None,
        details: bool | None = True,
    ) -> T:
        """Request a single scan report

        Args:
            report_id: UUID of an existing report
            filter_string: Filter term to use to filter results in the report
            filter_id: UUID of filter to use to filter results in the report
            delta_report_id: UUID of an existing report to compare report to.
            report_format_id: UUID of report format to use
                              or ReportFormatType (enum)
            report_config_id: UUID of report format config to use
            ignore_pagination: Whether to ignore the filter terms "first" and
                "rows".
            details: Request additional report information details
                     defaults to True
        """
        return self._send_request_and_transform_response(
            Reports.get_report(
                report_id,
                filter_string=filter_string,
                filter_id=filter_id,
                delta_report_id=delta_report_id,
                report_format_id=report_format_id,
                report_config_id=report_config_id,
                ignore_pagination=ignore_pagination,
                details=details,
            )
        )

    def get_reports(
        self,
        *,
        filter_string: str | None = None,
        filter_id: EntityID | None = None,
        note_details: bool | None = None,
        override_details: bool | None = None,
        ignore_pagination: bool | None = None,
        details: bool | None = None,
    ) -> T:
        """Request a list of scan reports

        Args:
            filter_string: Filter term to use for the query
            filter_id: UUID of an existing filter to use for the query
            note_details: If notes are included, whether to include note details
            override_details: If overrides are included, whether to include
                override details
            ignore_pagination: Whether to ignore the filter terms "first" and
                "rows".
            details: Whether to exclude results
        """
        return self._send_request_and_transform_response(
            Reports.get_reports(
                filter_string=filter_string,
                filter_id=filter_id,
                note_details=note_details,
                override_details=override_details,
                ignore_pagination=ignore_pagination,
                details=details,
            )
        )

    def import_report(
        self,
        report: str,
        task_id: EntityID,
        *,
        in_assets: bool | None = None,
    ) -> T:
        """Import a scan Report from XML

        Args:
            report: Report XML as string to import. This XML must contain
                a :code:`<report>` root element.
            task_id: UUID of task to import report to
            in_asset: Whether to create or update assets using the report
        """
        return self._send_request_and_transform_response(
            Reports.import_report(report, task_id, in_assets=in_assets)
        )

    def delete_audit_report(self, report_id: EntityID) -> T:
        """Deletes an existing audit report

        Args:
            report_id: UUID of the report to be deleted.
        """
        return self._send_request_and_transform_response(
            AuditReports.delete_report(report_id)
        )

    def get_audit_report(
        self,
        report_id: EntityID,
        *,
        filter_string: str | None = None,
        filter_id: str | None = None,
        delta_report_id: EntityID | None = None,
        report_format_id: str | ReportFormatType | None = None,
        ignore_pagination: bool | None = None,
        details: bool | None = True,
    ) -> T:
        """Request a single audit report

        Args:
            report_id: UUID of an existing audit report
            filter_string: Filter term to use to filter results in the report
            filter_id: UUID of filter to use to filter results in the report
            delta_report_id: UUID of an existing report to compare report to.
            report_format_id: UUID of report format to use
                              or ReportFormatType (enum)
            ignore_pagination: Whether to ignore the filter terms "first" and
                "rows".
            details: Request additional report information details
                     defaults to True
        """
        return self._send_request_and_transform_response(
            AuditReports.get_report(
                report_id,
                filter_string=filter_string,
                filter_id=filter_id,
                delta_report_id=delta_report_id,
                report_format_id=report_format_id,
                ignore_pagination=ignore_pagination,
                details=details,
            )
        )

    def get_audit_reports(
        self,
        *,
        filter_string: str | None = None,
        filter_id: EntityID | None = None,
        note_details: bool | None = None,
        override_details: bool | None = None,
        ignore_pagination: bool | None = None,
        details: bool | None = None,
    ) -> T:
        """Request a list of audit reports

        Args:
            filter_string: Filter term to use for the query
            filter_id: UUID of an existing filter to use for the query
            note_details: If notes are included, whether to include note details
            override_details: If overrides are included, whether to include
                override details
            ignore_pagination: Whether to ignore the filter terms "first" and
                "rows".
            details: Whether to exclude results
        """
        return self._send_request_and_transform_response(
            AuditReports.get_reports(
                filter_string=filter_string,
                filter_id=filter_id,
                note_details=note_details,
                override_details=override_details,
                ignore_pagination=ignore_pagination,
                details=details,
            )
        )

    def create_filter(
        self,
        name: str,
        *,
        filter_type: FilterType | None = None,  # type: ignore[override]
        comment: str | None = None,
        term: str | None = None,
    ) -> T:
        """Create a new filter

        Args:
            name: Name of the new filter
            filter_type: Filter for entity type
            comment: Comment for the filter
            term: Filter term e.g. 'name=foo'
        """
        # override create_filter because of the different FilterType enum
        # this avoids warnings with type checkers
        return self._send_request_and_transform_response(
            Filters.create_filter(
                name, filter_type=filter_type, comment=comment, term=term
            )
        )

    def modify_filter(
        self,
        filter_id: EntityID,
        *,
        comment: str | None = None,
        name: str | None = None,
        term: str | None = None,
        filter_type: FilterType | None = None,  # type: ignore[override]
    ) -> T:
        """Modifies an existing filter.

        Args:
            filter_id: UUID of the filter to be modified
            comment: Comment on filter.
            name: Name of filter.
            term: Filter term.
            filter_type: Resource type filter applies to.
        """
        # override create_filter because of the different FilterType enum
        # this avoids warnings with type checkers
        return self._send_request_and_transform_response(
            Filters.modify_filter(
                filter_id,
                comment=comment,
                name=name,
                term=term,
                filter_type=filter_type,
            )
        )

    def clone_report_config(self, report_config_id: EntityID) -> T:
        """Clone a report config from an existing one

        Args:
            report_config_id: UUID of the existing report config
        """
        return self._send_request_and_transform_response(
            ReportConfigs.clone_report_config(report_config_id)
        )

    def delete_report_config(
        self,
        report_config_id: EntityID,
        *,
        ultimate: bool | None = False,
    ) -> T:
        """Deletes an existing report config

        Args:
            report_config_id: UUID of the report config to be deleted.
            ultimate: Whether to remove entirely, or to the trashcan.
        """
        return self._send_request_and_transform_response(
            ReportConfigs.delete_report_config(
                report_config_id, ultimate=ultimate
            )
        )

    def get_report_configs(
        self,
        *,
        filter_string: str | None = None,
        filter_id: EntityID | None = None,
        trash: bool | None = None,
        details: bool | None = None,
    ) -> T:
        """Request a list of report configs

        Args:
            filter_string: Filter term to use for the query
            filter_id: UUID of an existing filter to use for the query
            trash: Whether to get the trashcan report configs instead
            details: Include report config details
        """
        return self._send_request_and_transform_response(
            ReportConfigs.get_report_configs(
                filter_string=filter_string,
                filter_id=filter_id,
                trash=trash,
                details=details,
            )
        )

    def get_report_config(
        self,
        report_config_id: EntityID,
    ) -> T:
        """Request a single report config

        Args:
            report_config_id: UUID of an existing report config
        """
        return self._send_request_and_transform_response(
            ReportConfigs.get_report_config(report_config_id)
        )

    def create_report_config(
        self,
        name: str,
        report_format_id: EntityID | ReportFormatType,
        *,
        comment: str | None = None,
        params: Sequence[ReportConfigParameter] | None = None,
    ) -> T:
        """Create a report config

        Args:
            name: Name of the new report config
            report_format_id: UUID of the report format to be used or ReportFormatType.
            comment: An optional comment for the report config.
            params: A list of report config parameters.
        """
        return self._send_request_and_transform_response(
            ReportConfigs.create_report_config(
                name, report_format_id, comment=comment, params=params
            )
        )

    def modify_report_config(
        self,
        report_config_id: EntityID,
        *,
        name: str | None = None,
        comment: str | None = None,
        params: Sequence[ReportConfigParameter] | None = None,
    ) -> T:
        """Create a report config

        Args:
            name: Name of the report config
            report_config_id: UUID of the report config to be modified.
            comment: An optional comment for the report config.
            params: A list of report config parameters.
        """
        return self._send_request_and_transform_response(
            ReportConfigs.modify_report_config(
                report_config_id, name=name, comment=comment, params=params
            )
        )



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#


class GmpGetResultsTestMixin:
    def test_get_results(self):
        self.gmp.get_results()

        self.connection.send.has_been_called_with(b"<get_results/>")

    def test_get_results_with_filter_string(self):
        self.gmp.get_results(filter_string="foo=bar")

        self.connection.send.has_been_called_with(
            b'<get_results filter="foo=bar"/>'
        )

    def test_get_results_with_filter_id(self):
        self.gmp.get_results(filter_id="f1")

        self.connection.send.has_been_called_with(
            b'<get_results filt_id="f1"/>'
        )

    def test_get_results_with_note_details(self):
        self.gmp.get_results(note_details=True)

        self.connection.send.has_been_called_with(
            b'<get_results note_details="1"/>'
        )

        self.gmp.get_results(note_details=False)

        self.connection.send.has_been_called_with(
            b'<get_results note_details="0"/>'
        )

    def test_get_results_with_override_details(self):
        self.gmp.get_results(override_details=True)

        self.connection.send.has_been_called_with(
            b'<get_results override_details="1"/>'
        )

        self.gmp.get_results(override_details=False)

        self.connection.send.has_been_called_with(
            b'<get_results override_details="0"/>'
        )

    def test_get_results_with_details(self):
        self.gmp.get_results(details=True)

        self.connection.send.has_been_called_with(b'<get_results details="1"/>')

        self.gmp.get_results(details=False)

        self.connection.send.has_been_called_with(b'<get_results details="0"/>')

    def test_get_results_with_task_id(self):
        self.gmp.get_results(task_id="t1")

        self.connection.send.has_been_called_with(
            b'<get_results task_id="t1"/>'
        )



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from numbers import Integral

from gvm.errors import InvalidArgument
from gvm.protocols.core import Request
from gvm.utils import to_bool
from gvm.xml import XmlCommand

from .._entity_id import EntityID


class SystemReports:
    @classmethod
    def get_system_reports(
        cls,
        *,
        name: str | None = None,
        duration: int | None = None,
        start_time: str | None = None,
        end_time: str | None = None,
        brief: bool | None = None,
        slave_id: EntityID | None = None,
    ) -> Request:
        """Request a list of system reports

        Arguments:
            name: A string describing the required system report
            duration: The number of seconds into the past that the system report
                should include
            start_time: The start of the time interval the system report should
                include in ISO time format
            end_time: The end of the time interval the system report should
                include in ISO time format
            brief: Whether to include the actual system reports
            slave_id: UUID of GMP scanner from which to get the system reports
        """
        cmd = XmlCommand("get_system_reports")

        if name:
            cmd.set_attribute("name", name)

        if duration is not None:
            if not isinstance(duration, Integral):
                raise InvalidArgument(
                    "duration needs to be an integer number",
                    function=cls.get_system_reports.__name__,
                )

            cmd.set_attribute("duration", str(duration))

        if start_time:
            cmd.set_attribute("start_time", str(start_time))

        if end_time:
            cmd.set_attribute("end_time", str(end_time))

        if brief is not None:
            cmd.set_attribute("brief", to_bool(brief))

        if slave_id:
            cmd.set_attribute("slave_id", str(slave_id))

        return cmd



# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.gmp.requests.v225 import ResourceType


class GmpGetResourceNameTestMixin:
    def test_get_resource_name(self):
        self.gmp.get_resource_name(
            resource_type=ResourceType.ALERT, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="ALERT"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.CERT_BUND_ADV, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="CERT_BUND_ADV"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.CONFIG, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="CONFIG"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.CPE, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="CPE"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.CREDENTIAL, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="CREDENTIAL"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.CVE, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="CVE"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.DFN_CERT_ADV, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="DFN_CERT_ADV"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.FILTER, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="FILTER"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.GROUP, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="GROUP"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.HOST, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="HOST"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.NOTE, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="NOTE"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.NVT, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="NVT"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.OS, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="OS"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.PERMISSION, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="PERMISSION"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.PORT_LIST, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="PORT_LIST"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.REPORT_FORMAT, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="REPORT_FORMAT"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.REPORT, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="REPORT"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.RESULT, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="RESULT"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.ROLE, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="ROLE"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.SCANNER, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="SCANNER"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.SCHEDULE, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="SCHEDULE"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.TARGET, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="TARGET"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.TASK, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="TASK"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.TLS_CERTIFICATE, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="TLS_CERTIFICATE"/>'
        )

        self.gmp.get_resource_name(
            resource_type=ResourceType.USER, resource_id="i1"
        )

        self.connection.send.has_been_called_with(
            b'<get_resource_names resource_id="i1" type="USER"/>'
        )

    def test_get_resource_name_missing_resource_type(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_resource_name(resource_id="i1", resource_type=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_resource_name(resource_id="i1", resource_type="")

        with self.assertRaises(RequiredArgument):
            self.gmp.get_resource_name("i1", "")

    def test_get_resource_name_invalid_resource_type(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.get_resource_name(resource_id="i1", resource_type="foo")

    def test_get_resource_name_missing_resource_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.get_resource_name(
                resource_id="", resource_type=ResourceType.CPE
            )

        with self.assertRaises(RequiredArgument):
            self.gmp.get_resource_name("", resource_type=ResourceType.CPE)

        with self.assertRaises(RequiredArgument):
            self.gmp.get_resource_name(
                resource_id=None, resource_type=ResourceType.CPE
            )



# SPDX-FileCopyrightText: 2023-2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv226.entities.report_configs import (
    GMPCloneReportConfigTestMixin,
    GMPCreateReportConfigTestMixin,
    GMPDeleteReportConfigTestMixin,
    GMPGetReportConfigsTestMixin,
    GMPGetReportConfigTestMixin,
    GMPModifyReportConfigTestMixin,
)
from ...gmpv227 import GMPTestCase


class GMPCloneReportConfigTestCase(GMPCloneReportConfigTestMixin, GMPTestCase):
    pass


class GMPCreateReportConfigTestCase(
    GMPCreateReportConfigTestMixin, GMPTestCase
):
    pass


class GMPDeleteReportConfigTestCase(
    GMPDeleteReportConfigTestMixin, GMPTestCase
):
    pass


class GMPGetReportConfigTestCase(GMPGetReportConfigTestMixin, GMPTestCase):
    pass


class GMPGetReportConfigsTestCase(GMPGetReportConfigsTestMixin, GMPTestCase):
    pass


class GMPModifyReportConfigTestCase(
    GMPModifyReportConfigTestMixin, GMPTestCase
):
    pass



# SPDX-FileCopyrightText: 2019-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import RequiredArgument


class GmpCreateTicketTestMixin:
    def test_create_ticket(self):
        self.gmp.create_ticket(
            result_id="r1", assigned_to_user_id="u1", note="lorem ipsum"
        )

        self.connection.send.has_been_called_with(
            b"<create_ticket>"
            b'<result id="r1"/>'
            b"<assigned_to>"
            b'<user id="u1"/>'
            b"</assigned_to>"
            b"<open_note>lorem ipsum</open_note>"
            b"</create_ticket>"
        )

    def test_create_ticket_with_comment(self):
        self.gmp.create_ticket(
            result_id="r1",
            assigned_to_user_id="u1",
            note="lorem ipsum",
            comment="bar",
        )

        self.connection.send.has_been_called_with(
            b"<create_ticket>"
            b'<result id="r1"/>'
            b"<assigned_to>"
            b'<user id="u1"/>'
            b"</assigned_to>"
            b"<open_note>lorem ipsum</open_note>"
            b"<comment>bar</comment>"
            b"</create_ticket>"
        )

    def test_create_ticket_missing_result_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_ticket(
                result_id="", assigned_to_user_id="u1", note="lorem ipsum"
            )

    def test_create_ticket_missing_assigned_to_user_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_ticket(
                result_id="r1", assigned_to_user_id="", note="lorem ipsum"
            )

    def test_create_ticket_missing_open_note(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.create_ticket(
                result_id="r1", assigned_to_user_id="u1", note=""
            )



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import RequiredArgument


class GmpDeleteUserTestMixin:
    def test_delete_user_with_user_id(self):
        self.gmp.delete_user("a1")

        self.connection.send.has_been_called_with(
            b'<delete_user user_id="a1"/>'
        )

        self.gmp.delete_user(user_id="a1")

        self.connection.send.has_been_called_with(
            b'<delete_user user_id="a1"/>'
        )

    def test_delete_user_with_inheritor_id(self):
        self.gmp.delete_user("a1", inheritor_id="u1")

        self.connection.send.has_been_called_with(
            b'<delete_user user_id="a1" inheritor_id="u1"/>'
        )

    def test_delete_user_with_name(self):
        self.gmp.delete_user(name="foo")

        self.connection.send.has_been_called_with(b'<delete_user name="foo"/>')

    def test_delete_user_with_inheritor_name(self):
        self.gmp.delete_user("a1", inheritor_name="foo")

        self.connection.send.has_been_called_with(
            b'<delete_user user_id="a1" inheritor_name="foo"/>'
        )

    def test_delete_user_missing_user_id_and_name(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.delete_user(None)

        with self.assertRaises(RequiredArgument):
            self.gmp.delete_user("")

        with self.assertRaises(RequiredArgument):
            self.gmp.delete_user(user_id="", name="")



# SPDX-FileCopyrightText: 2023-2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.entities.credentials import (
    GmpCloneCredentialTestMixin,
    GmpCreateCredentialTestMixin,
    GmpDeleteCredentialTestMixin,
    GmpGetCredentialsTestMixin,
    GmpGetCredentialTestMixin,
    GmpModifyCredentialTestMixin,
)
from ...gmpv227 import GMPTestCase


class GMPCloneCredentialTestCase(GmpCloneCredentialTestMixin, GMPTestCase):
    pass


class GMPCreateCredentialTestCase(GmpCreateCredentialTestMixin, GMPTestCase):
    pass


class GMPDeleteCredentialTestCase(GmpDeleteCredentialTestMixin, GMPTestCase):
    pass


class GMPGetCredentialTestCase(GmpGetCredentialTestMixin, GMPTestCase):
    pass


class GMPGetCredentialsTestCase(GmpGetCredentialsTestMixin, GMPTestCase):
    pass


class GMPModifyCredentialTestCase(GmpModifyCredentialTestMixin, GMPTestCase):
    pass



# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later


from gvm._enum import Enum
from gvm.errors import RequiredArgument
from gvm.protocols.core import Request
from gvm.xml import XmlCommand


class FeedType(Enum):
    """Enum for feed types"""

    NVT = "NVT"
    CERT = "CERT"
    SCAP = "SCAP"
    GVMD_DATA = "GVMD_DATA"


class Feed:
    @staticmethod
    def get_feeds() -> Request:
        """Request the list of feeds"""
        return XmlCommand("get_feeds")

    @classmethod
    def get_feed(cls, feed_type: FeedType | str) -> Request:
        """Request a single feed

        Arguments:
            feed_type: Type of single feed to get: NVT, CERT or SCAP
        """
        if not feed_type:
            raise RequiredArgument(
                function=cls.get_feed.__name__, argument="feed_type"
            )

        if not isinstance(feed_type, FeedType):
            feed_type = FeedType(feed_type)

        cmd = XmlCommand("get_feeds")
        cmd.set_attribute("type", feed_type.value)

        return cmd



# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.system.system_reports import GmpGetSystemReportsTestMixin
from ...gmpv226 import GMPTestCase


class GMPGetSystemReportsTestCase(GmpGetSystemReportsTestMixin, GMPTestCase):
    pass



# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""
API wrapper for interacting with the /scans endpoints of the openvasd HTTP API.
"""

import urllib.parse
from dataclasses import asdict, dataclass, field
from enum import Enum
from typing import Any
from uuid import UUID

import httpx

from gvm.errors import InvalidArgumentType

from ._api import OpenvasdAPI

ID = str | UUID


@dataclass
class PortRange:
    """
    Represents a range of ports.

    Attributes:
        start: The starting port number.
        end: The ending port number.
    """

    start: int
    end: int


@dataclass
class Port:
    """
    Represents a port configuration for scanning.

    Attributes:
        protocol: The protocol to use ("tcp" or "udp").
        range: A list of port ranges to scan.
    """

    protocol: str  # e.g., "tcp", "udp"
    range: list[PortRange]


@dataclass
class CredentialUP:
    """
    Represents username/password credentials for a service.

    Attributes:
        username: The login username.
        password: The login password.
        privilege_username: Optional privilege escalation username.
        privilege_password: Optional privilege escalation password.
    """

    username: str
    password: str
    privilege_username: str | None = None
    privilege_password: str | None = None


@dataclass
class CredentialKRB5:
    """
    Represents Kerberos credentials.

    Attributes:
        username: Kerberos username.
        password: Kerberos password.
        realm: Kerberos realm.
        kdc: Key Distribution Center hostname.
    """

    username: str
    password: str
    realm: str
    kdc: str


@dataclass
class CredentialUSK:
    """
    Represents credentials using a user/SSH key combination.

    Attributes:
        username: SSH username.
        password: Password for SSH key (if encrypted).
        private: Private key content or reference.
        privilege_username: Optional privilege escalation username.
        privilege_password: Optional privilege escalation password.
    """

    username: str
    password: str
    private: str
    privilege_username: str | None = None
    privilege_password: str | None = None


@dataclass
class CredentialSNMP:
    """
    Represents SNMP credentials.

    Attributes:
        username: SNMP username.
        password: SNMP authentication password.
        community: SNMP community string.
        auth_algorithm: Authentication algorithm (e.g., "md5").
        privacy_password: Privacy password for SNMPv3.
        privacy_algorithm: Privacy algorithm (e.g., "aes").
    """

    username: str
    password: str
    community: str
    auth_algorithm: str
    privacy_password: str
    privacy_algorithm: str


@dataclass
class Credential:
    """
    Represents a full credential configuration for a specific service.

    Attributes:
        service: Name of the service (e.g., "ssh", "snmp").
        port: Port number associated with the service.
        up: Optional username/password credentials.
        krb5: Optional Kerberos credentials.
        usk: Optional user/SSH key credentials.
        snmp: Optional SNMP credentials.
    """

    service: str
    port: int
    up: CredentialUP | None = None
    krb5: CredentialKRB5 | None = None
    usk: CredentialUSK | None = None
    snmp: CredentialSNMP | None = None


@dataclass
class Target:
    """
    Represents the scan target configuration.

    Attributes:
        hosts: List of target IPs or hostnames.
        excluded_hosts: List of IPs or hostnames to exclude.
        ports: List of port configurations.
        credentials: List of credentials to use during scanning.
        alive_test_ports: Port ranges used to test if hosts are alive.
        alive_test_methods: Methods used to check if hosts are alive (e.g., "icmp").
        reverse_lookup_unify: Whether to unify reverse lookup results.
        reverse_lookup_only: Whether to rely solely on reverse DNS lookups.
    """

    hosts: list[str]
    excluded_hosts: list[str] = field(default_factory=list)
    ports: list[Port] = field(default_factory=list)
    credentials: list[Credential] = field(default_factory=list)
    alive_test_ports: list[Port] = field(default_factory=list)
    alive_test_methods: list[str] = field(default_factory=list)
    reverse_lookup_unify: bool = False
    reverse_lookup_only: bool = False


@dataclass
class VTParameter:
    """
    Represents a parameter for a specific vulnerability test.

    Attributes:
        id: Identifier of the VT parameter.
        value: Value to assign to the parameter.
    """

    id: int
    value: str


@dataclass
class VTSelection:
    """
    Represents a selected vulnerability test (VT) and its parameters.

    Attributes:
        oid: The OID (Object Identifier) of the VT.
        parameters: A list of parameters to customize VT behavior.
    """

    oid: str
    parameters: list[VTParameter] = field(default_factory=list)


@dataclass
class ScanPreference:
    """
    Represents a scan-level preference or configuration option.

    Attributes:
        id: Preference ID or name (e.g., "max_checks", "scan_speed").
        value: The value assigned to the preference.
    """

    id: str
    value: str


def _to_dict(obj: Any) -> Any:
    """Recursively convert dataclass instances to dictionaries."""
    if isinstance(obj, list):
        return [_to_dict(item) for item in obj]
    elif hasattr(obj, "__dataclass_fields__"):
        return {k: _to_dict(v) for k, v in asdict(obj).items() if v is not None}
    return obj


class ScanAction(str, Enum):
    """
    Enumeration of valid scan actions supported by the openvasd API.

    This enum defines the allowed actions that can be performed on a scan.
    Using an enum helps ensure type safety and prevents invalid action strings
    from being passed to the API.

    Values:
        START: Initiates the scan execution.
        STOP: Terminates an ongoing scan.
    """

    START = "start"  # Start the scan
    STOP = "stop"  # Stop the scan


class ScansAPI(OpenvasdAPI):
    """
    Provides access to scan-related operations in the openvasd HTTP API.

    Includes methods for creating, starting, stopping, and retrieving scan details
    and results.
    """

    def create(
        self,
        target: Target,
        vt_selection: list[VTSelection],
        *,
        scan_preferences: list[ScanPreference] | None = None,
    ) -> httpx.Response:
        """
        Create a new scan with the specified target configuration and VT selection.

        Args:
            target: A `Target` dataclass instance describing the scan target(s), including hosts, ports, credentials, and alive test settings.
            vt_selection: A list of `VTSelection` instances specifying which vulnerability tests (VTs) to include in the scan.
            scan_preferences: Optional list of `ScanPreference` instances to customize scan behavior (e.g., number of threads, timeout values).

        Returns:
            The full HTTP response returned by the POST /scans request.

        Raises:
            httpx.HTTPStatusError: If the server responds with an error status
                and the exception is not suppressed.

        See: POST /scans in the openvasd API documentation.
        """
        request_json = {
            "target": _to_dict(target),
            "vts": _to_dict(vt_selection),
        }
        if scan_preferences:
            request_json["scan_preferences"] = _to_dict(scan_preferences)

        try:
            response = self._client.post("/scans", json=request_json)
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise

    def delete(self, scan_id: ID) -> int:
        """
        Delete a scan by its ID.

        Args:
            scan_id: The scan identifier.

        Returns:
            The HTTP status code returned by the server on success,
            or the error status code returned by the server on failure.

        Raises:
            httpx.HTTPStatusError: If the server responds with an error status
                and the exception is not suppressed.

        See: DELETE /scans/{id} in the openvasd API documentation.
        """
        try:
            response = self._client.delete(
                f"/scans/{urllib.parse.quote(str(scan_id))}"
            )
            response.raise_for_status()
            return response.status_code
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response.status_code
            raise

    def get_all(self) -> httpx.Response:
        """
        Retrieve the list of all available scans.

        Returns:
            The full HTTP response of the GET /scans request.

        Raises:
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: GET /scans in the openvasd API documentation.
        """
        try:
            response = self._client.get("/scans")
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise

    def get(self, scan_id: ID) -> httpx.Response:
        """
        Retrieve metadata of a single scan by ID.

        Args:
            scan_id: The scan identifier.

        Returns:
            The full HTTP response of the GET /scans/{id} request.

        Raises:
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: GET /scans/{id} in the openvasd API documentation.
        """
        try:
            response = self._client.get(
                f"/scans/{urllib.parse.quote(str(scan_id))}"
            )
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise

    def get_results(
        self,
        scan_id: ID,
        *,
        range_start: int | None = None,
        range_end: int | None = None,
    ) -> httpx.Response:
        """
        Retrieve a range of results for a given scan.

        Args:
            scan_id: The scan identifier.
            range_start: Optional start index for paginated results.
            range_end: Optional end index for paginated results.

        Returns:
            The full HTTP response of the GET /scans/{id}/results request.

        Raises:
            InvalidArgumentType: If provided range values are not integers.
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: GET /scans/{id}/results in the openvasd API documentation.
        """
        params = {}
        if range_start is not None:
            if not isinstance(range_start, int):
                raise InvalidArgumentType("range_start")
            if range_end is not None:
                if not isinstance(range_end, int):
                    raise InvalidArgumentType("range_end")
                params["range"] = f"{range_start}-{range_end}"
            else:
                params["range"] = str(range_start)
        elif range_end is not None:
            if not isinstance(range_end, int):
                raise InvalidArgumentType("range_end")
            params["range"] = f"0-{range_end}"

        try:
            response = self._client.get(
                f"/scans/{urllib.parse.quote(str(scan_id))}/results",
                params=params,
            )
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise

    def get_result(
        self,
        scan_id: ID,
        result_id: ID,
    ) -> httpx.Response:
        """
        Retrieve a specific scan result.

        Args:
            scan_id: The scan identifier.
            result_id: The specific result ID to fetch.

        Returns:
            The full HTTP response of the GET /scans/{id}/results/{rid} request.

        Raises:
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: GET /scans/{id}/results/{rid} in the openvasd API documentation.
        """
        try:
            response = self._client.get(
                f"/scans/{urllib.parse.quote(str(scan_id))}/results/{urllib.parse.quote(str(result_id))}"
            )
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise

    def get_status(self, scan_id: ID) -> httpx.Response:
        """
        Retrieve the status of a scan.

        Args:
            scan_id: The scan identifier.

        Returns:
            The full HTTP response of the GET /scans/{id}/status request.

        Raises:
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: GET /scans/{id}/status in the openvasd API documentation.
        """
        try:
            response = self._client.get(
                f"/scans/{urllib.parse.quote(str(scan_id))}/status"
            )
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise

    def _run_action(self, scan_id: ID, action: ScanAction) -> int:
        """
        Perform a scan action (start or stop) for the given scan ID.

        Args:
            scan_id: The unique identifier of the scan.
            action: A member of the ScanAction enum (e.g., ScanAction.START or ScanAction.STOP).

        Returns:
            The HTTP status code returned by the server on success,
            or the error status code returned by the server on failure.

        Raises:
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: POST /scans/{id} in the openvasd API documentation.
        """
        try:
            response = self._client.post(
                f"/scans/{urllib.parse.quote(str(scan_id))}",
                json={"action": str(action.value)},
            )
            response.raise_for_status()
            return response.status_code
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response.status_code
            raise

    def start(self, scan_id: ID) -> int:
        """
        Start the scan identified by the given scan ID.

        Args:
            scan_id: The unique identifier of the scan.

        Returns:
            HTTP status code (e.g., 200) if successful, or error code (e.g., 404, 500) if the request fails,
            and safe is False.

        Raises:
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: POST /scans/{id} with action=start in the openvasd API documentation.
        """
        return self._run_action(scan_id, ScanAction.START)

    def stop(self, scan_id: ID) -> int:
        """
        Stop the scan identified by the given scan ID.

        Args:
            scan_id: The unique identifier of the scan.

        Returns:
            HTTP status code (e.g., 200) if successful, or error code (e.g., 404, 500) if the request fails,
            and safe is False.

        Raises:
            httpx.HTTPStatusError: If the request fails and exceptions are not suppressed.

        See: POST /scans/{id} with action=stop in the openvasd API documentation.
        """
        return self._run_action(scan_id, ScanAction.STOP)

    def get_preferences(self) -> httpx.Response:
        """
        Retrieve all available scan preferences from the scanner.

        Returns:
            The full HTTP response of the GET /scans/preferences request.

        Raises:
            httpx.HTTPStatusError: If the server responds with an error status
                and the exception is not suppressed.

        See: GET /scans/preferences in the openvasd API documentation.
        """
        try:
            response = self._client.get("/scans/preferences")
            response.raise_for_status()
            return response
        except httpx.HTTPStatusError as e:
            if self._suppress_exceptions:
                return e.response
            raise



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

import unittest

from gvm.protocols.ospv1 import Osp

from .. import MockConnection


class OSPDeleteScanTestCase(unittest.TestCase):
    def setUp(self):
        self.connection = MockConnection()
        self.osp = Osp(self.connection)

    def test_delete_scan(self):
        self.osp.delete_scan(scan_id="123-456")

        self.connection.send.has_been_called_with(
            b'<delete_scan scan_id="123-456"/>'
        )

    def test_delete_scan_without_id(self):
        with self.assertRaises(ValueError):
            self.osp.delete_scan(None)

        with self.assertRaises(ValueError):
            self.osp.delete_scan("")


if __name__ == "__main__":
    unittest.main()



# SPDX-FileCopyrightText: 2020-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.gmp.requests.v224 import TicketStatus


class GmpModifyTicketTestMixin:
    def test_modify_ticket(self):
        self.gmp.modify_ticket("t1")

        self.connection.send.has_been_called_with(
            b'<modify_ticket ticket_id="t1"/>'
        )

        self.gmp.modify_ticket(ticket_id="t1")

        self.connection.send.has_been_called_with(
            b'<modify_ticket ticket_id="t1"/>'
        )

    def test_missing_ticket_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_ticket("")

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_ticket(None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_ticket(ticket_id=None)

    def test_modify_ticket_with_comment(self):
        self.gmp.modify_ticket(ticket_id="t1", comment="bar")

        self.connection.send.has_been_called_with(
            b'<modify_ticket ticket_id="t1">'
            b"<comment>bar</comment>"
            b"</modify_ticket>"
        )

    def test_modify_ticket_with_assigned_to_user_id(self):
        self.gmp.modify_ticket(ticket_id="t1", assigned_to_user_id="u1")

        self.connection.send.has_been_called_with(
            b'<modify_ticket ticket_id="t1">'
            b"<assigned_to>"
            b'<user id="u1"/>'
            b"</assigned_to>"
            b"</modify_ticket>"
        )

    def test_modify_ticket_invalid_status(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_ticket(ticket_id="t1", status="foobar", note="bar")

    def test_modify_ticket_open(self):
        self.gmp.modify_ticket(
            ticket_id="t1", status=TicketStatus.OPEN, note="lorem ipsum"
        )

        self.connection.send.has_been_called_with(
            b'<modify_ticket ticket_id="t1">'
            b"<status>Open</status>"
            b"<open_note>lorem ipsum</open_note>"
            b"</modify_ticket>"
        )

    def test_modify_ticket_fixed(self):
        self.gmp.modify_ticket(
            ticket_id="t1", status=TicketStatus.FIXED, note="lorem ipsum"
        )

        self.connection.send.has_been_called_with(
            b'<modify_ticket ticket_id="t1">'
            b"<status>Fixed</status>"
            b"<fixed_note>lorem ipsum</fixed_note>"
            b"</modify_ticket>"
        )

    def test_modify_ticket_closed(self):
        self.gmp.modify_ticket(
            ticket_id="t1", status=TicketStatus.CLOSED, note="lorem ipsum"
        )

        self.connection.send.has_been_called_with(
            b'<modify_ticket ticket_id="t1">'
            b"<status>Closed</status>"
            b"<closed_note>lorem ipsum</closed_note>"
            b"</modify_ticket>"
        )

    def test_modify_ticket_status_without_note(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_ticket(ticket_id="t1", status=TicketStatus.CLOSED)

    def test_modify_ticket_note_without_status(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_ticket(ticket_id="t1", note="foo")



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.gmp.requests.v224 import EntityType


class GmpModifyTagTestMixin:
    def test_modify_tag(self):
        self.gmp.modify_tag(tag_id="t1")

        self.connection.send.has_been_called_with(b'<modify_tag tag_id="t1"/>')

    def test_modify_tag_missing_tag_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.modify_tag(tag_id=None)

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_tag(tag_id="")

    def test_modify_tag_with_comment(self):
        self.gmp.modify_tag(tag_id="t1", comment="foo")

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1"><comment>foo</comment></modify_tag>'
        )

    def test_modify_tag_with_value(self):
        self.gmp.modify_tag(tag_id="t1", value="foo")

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1"><value>foo</value></modify_tag>'
        )

    def test_modify_tag_with_name(self):
        self.gmp.modify_tag(tag_id="t1", name="foo")

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1"><name>foo</name></modify_tag>'
        )

    def test_modify_tag_with_active(self):
        self.gmp.modify_tag(tag_id="t1", active=True)

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1"><active>1</active></modify_tag>'
        )

        self.gmp.modify_tag(tag_id="t1", active=False)

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1"><active>0</active></modify_tag>'
        )

    def test_modify_tag_with_resource_filter_and_type(self):
        self.gmp.modify_tag(
            tag_id="t1",
            resource_filter="name=foo",
            resource_type=EntityType.TASK,
        )

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b'<resources filter="name=foo">'
            b"<type>task</type>"
            b"</resources>"
            b"</modify_tag>"
        )

    def test_modify_tag_with_resource_filter_and_type_audit(self):
        self.gmp.modify_tag(
            tag_id="t1",
            resource_filter="name=foo",
            resource_type=EntityType.AUDIT,
        )

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b'<resources filter="name=foo">'
            b"<type>task</type>"
            b"</resources>"
            b"</modify_tag>"
        )

    def test_modify_tag_with_resource_filter_and_type_policy(self):
        self.gmp.modify_tag(
            tag_id="t1",
            resource_filter="name=foo",
            resource_type=EntityType.POLICY,
        )

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b'<resources filter="name=foo">'
            b"<type>config</type>"
            b"</resources>"
            b"</modify_tag>"
        )

    def test_modify_tag_with_resource_action_filter_and_type(self):
        self.gmp.modify_tag(
            tag_id="t1",
            resource_action="set",
            resource_filter="name=foo",
            resource_type=EntityType.TASK,
        )

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b'<resources action="set" filter="name=foo">'
            b"<type>task</type>"
            b"</resources>"
            b"</modify_tag>"
        )

    def test_modify_tag_with_resource_ids_and_type(self):
        self.gmp.modify_tag(
            tag_id="t1", resource_ids=["r1"], resource_type=EntityType.TASK
        )

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b"<resources>"
            b'<resource id="r1"/>'
            b"<type>task</type>"
            b"</resources>"
            b"</modify_tag>"
        )

    def test_modify_tag_with_resource_action_ids_and_type(self):
        self.gmp.modify_tag(
            tag_id="t1",
            resource_action="set",
            resource_ids=["r1"],
            resource_type=EntityType.TASK,
        )

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b'<resources action="set">'
            b'<resource id="r1"/>'
            b"<type>task</type>"
            b"</resources>"
            b"</modify_tag>"
        )

    def test_modify_tag_with_missing_resource_filter_or_ids_andtype(self):
        self.gmp.modify_tag(tag_id="t1", resource_action="add")

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1"><resources action="add"/></modify_tag>'
        )

    def test_modify_tag_with_missing_resource_type(self):
        self.gmp.modify_tag(tag_id="t1", resource_ids=["r1"])

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b"<resources>"
            b'<resource id="r1"/>'
            b"</resources>"
            b"</modify_tag>"
        )

        with self.assertRaises(RequiredArgument):
            self.gmp.modify_tag(tag_id="t1", resource_filter="name=foo")

    def test_modify_tag_with_invalid_resource_type(self):
        with self.assertRaises(InvalidArgument):
            self.gmp.modify_tag(
                tag_id="t1", resource_type="foo", resource_filter="name=foo"
            )

    def test_modify_tag_with_missing_resource_filter_and_ids(self):
        self.gmp.modify_tag(tag_id="t1", resource_type=EntityType.TASK)

        self.connection.send.has_been_called_with(
            b'<modify_tag tag_id="t1">'
            b"<resources>"
            b"<type>task</type>"
            b"</resources>"
            b"</modify_tag>"
        )



# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.system.trashcan import (
    GmpEmptyTrashcanTestMixin,
    GmpRestoreFromTrashcanTestMixin,
)
from ...gmpv226 import GMPTestCase


class GMPEmptyTrashcanTestCase(GmpEmptyTrashcanTestMixin, GMPTestCase):
    pass


class GMPRestoreFromTrashcanTestCase(
    GmpRestoreFromTrashcanTestMixin, GMPTestCase
):
    pass



# SPDX-FileCopyrightText: 2023-2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpnext import GMPTestCase
from .agents.test_delete_agents import (
    GmpDeleteAgentsTestMixin,
)
from .agents.test_get_agents import (
    GmpGetAgentsTestMixin,
)
from .agents.test_modify_agent_controller_scan_config import (
    GmpModifyAgentControllerScanConfigTestMixin,
)
from .agents.test_modify_agents import (
    GmpModifyAgentsTestMixin,
)
from .agents.test_sync_agents import GmpSyncAgentsTestMixin


class GMPGetAgentsTestCase(GmpGetAgentsTestMixin, GMPTestCase):
    pass


class GMPModifyAgentsTestCase(GmpModifyAgentsTestMixin, GMPTestCase):
    pass


class GMPDeleteAgentsTestCase(GmpDeleteAgentsTestMixin, GMPTestCase):
    pass


class GMPModifyAgentControllerScanConfigTestCase(
    GmpModifyAgentControllerScanConfigTestMixin, GMPTestCase
):
    pass


class GMPSyncAgentsTestCase(GmpSyncAgentsTestMixin, GMPTestCase):
    pass



# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

import unittest

from gvm.errors import RequiredArgument
from gvm.protocols.gmp.requests.v226 import AuditReports


class AuditReportsTestCase(unittest.TestCase):
    def test_delete_report(self):
        request = AuditReports.delete_report("report_id")
        self.assertEqual(
            bytes(request),
            b'<delete_report report_id="report_id"/>',
        )

    def test_delete_report_missing_report_id(self):
        with self.assertRaises(RequiredArgument):
            AuditReports.delete_report(None)

        with self.assertRaises(RequiredArgument):
            AuditReports.delete_report("")

    def test_get_report(self):
        request = AuditReports.get_report("report_id")
        self.assertEqual(
            bytes(request),
            b'<get_reports report_id="report_id" usage_type="audit" details="1"/>',
        )

    def test_get_report_with_filter_string(self):
        request = AuditReports.get_report(
            "report_id", filter_string="filter_string"
        )
        self.assertEqual(
            bytes(request),
            b'<get_reports report_id="report_id" usage_type="audit" filter="filter_string" details="1"/>',
        )

    def test_get_report_with_filter_id(self):
        request = AuditReports.get_report("report_id", filter_id="filter_id")
        self.assertEqual(
            bytes(request),
            b'<get_reports report_id="report_id" usage_type="audit" filt_id="filter_id" details="1"/>',
        )

    def test_get_report_with_delta_report_id(self):
        request = AuditReports.get_report(
            "report_id", delta_report_id="delta_report_id"
        )
        self.assertEqual(
            bytes(request),
            b'<get_reports report_id="report_id" usage_type="audit" delta_report_id="delta_report_id" details="1"/>',
        )

    def test_get_report_with_report_format_id(self):
        request = AuditReports.get_report(
            "report_id", report_format_id="report_format_id"
        )
        self.assertEqual(
            bytes(request),
            b'<get_reports report_id="report_id" usage_type="audit" format_id="report_format_id" details="1"/>',
        )

    def test_get_report_with_ignore_pagination(self):
        request = AuditReports.get_report("report_id", ignore_pagination=True)
        self.assertEqual(
            bytes(request),
            b'<get_reports report_id="report_id" usage_type="audit" ignore_pagination="1" details="1"/>',
        )

    def test_get_report_missing_report_id(self):
        with self.assertRaises(RequiredArgument):
            AuditReports.get_report(None)

        with self.assertRaises(RequiredArgument):
            AuditReports.get_report("")

    def test_get_reports(self):
        request = AuditReports.get_reports()
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit"/>',
        )

    def test_get_reports_with_filter_string(self):
        request = AuditReports.get_reports(filter_string="filter_string")
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" report_filter="filter_string"/>',
        )

    def test_get_reports_with_filter_id(self):
        request = AuditReports.get_reports(filter_id="filter_id")
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" report_filt_id="filter_id"/>',
        )

    def test_get_reports_with_note_details(self):
        request = AuditReports.get_reports(note_details=True)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" note_details="1"/>',
        )

        request = AuditReports.get_reports(note_details=False)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" note_details="0"/>',
        )

    def test_get_reports_with_override_details(self):
        request = AuditReports.get_reports(override_details=True)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" override_details="1"/>',
        )

        request = AuditReports.get_reports(override_details=False)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" override_details="0"/>',
        )

    def test_get_reports_with_details(self):
        request = AuditReports.get_reports(details=True)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" details="1"/>',
        )

        request = AuditReports.get_reports(details=False)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" details="0"/>',
        )

    def test_get_reports_with_ignore_pagination(self):
        request = AuditReports.get_reports(ignore_pagination=True)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" ignore_pagination="1"/>',
        )

        request = AuditReports.get_reports(ignore_pagination=False)
        self.assertEqual(
            bytes(request),
            b'<get_reports usage_type="audit" ignore_pagination="0"/>',
        )



# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from .test_clone_scan_config import GmpCloneScanConfigTestMixin
from .test_create_scan_config import GmpCreateScanConfigTestMixin
from .test_delete_scan_config import GmpDeleteScanConfigTestMixin
from .test_get_scan_config import GmpGetScanConfigTestMixin
from .test_get_scan_config_preference import GmpGetScanConfigPreferenceTestMixin
from .test_get_scan_config_preferences import (
    GmpGetScanConfigPreferencesTestMixin,
)
from .test_get_scan_configs import GmpGetScanConfigsTestMixin
from .test_import_scan_config import GmpImportScanConfigTestMixin
from .test_modify_scan_config_set_comment import (
    GmpModifyScanConfigSetCommentTestMixin,
)
from .test_modify_scan_config_set_family_selection import (
    GmpModifyScanConfigSetFamilySelectionTestMixin,
)
from .test_modify_scan_config_set_name import (
    GmpModifyScanConfigSetNameTestMixin,
)
from .test_modify_scan_config_set_nvt_preference import (
    GmpModifyScanConfigSetNvtPreferenceTestMixin,
)
from .test_modify_scan_config_set_nvt_selection import (
    GmpModifyScanConfigSetNvtSelectionTestMixin,
)
from .test_modify_scan_config_set_scanner_preference import (
    GmpModifyScanConfigSetScannerPreferenceTestMixin,
)

__all__ = (
    "GmpCloneScanConfigTestMixin",
    "GmpCreateScanConfigTestMixin",
    "GmpDeleteScanConfigTestMixin",
    "GmpGetScanConfigPreferenceTestMixin",
    "GmpGetScanConfigPreferencesTestMixin",
    "GmpGetScanConfigTestMixin",
    "GmpGetScanConfigsTestMixin",
    "GmpImportScanConfigTestMixin",
    "GmpModifyScanConfigSetCommentTestMixin",
    "GmpModifyScanConfigSetFamilySelectionTestMixin",
    "GmpModifyScanConfigSetNameTestMixin",
    "GmpModifyScanConfigSetNvtPreferenceTestMixin",
    "GmpModifyScanConfigSetNvtSelectionTestMixin",
    "GmpModifyScanConfigSetScannerPreferenceTestMixin",
)



# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

import unittest

from gvm.errors import InvalidArgument, RequiredArgument
from gvm.protocols.gmp.requests.v224 import AliveTest, Targets


class TargetsTestCase(unittest.TestCase):
    def test_create_target_missing_name(self):
        with self.assertRaises(RequiredArgument):
            Targets.create_target(None, hosts=["foo"])

        with self.assertRaises(RequiredArgument):
            Targets.create_target(name=None, hosts=["foo"])

        with self.assertRaises(RequiredArgument):
            Targets.create_target("", hosts=["foo"])

    def test_create_target_missing_hosts(self):
        with self.assertRaises(RequiredArgument):
            Targets.create_target(name="foo")

    def test_create_target_with_hosts(self):
        request = Targets.create_target("foo", hosts=["foo"])

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"</create_target>",
        )

        request = Targets.create_target("foo", hosts=["foo", "bar"])

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo,bar</hosts>"
            b"</create_target>",
        )

    def test_create_target_with_asset_hosts_filter(self):
        request = Targets.create_target("foo", asset_hosts_filter="name=foo")

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b'<asset_hosts filter="name=foo"/>'
            b"</create_target>",
        )

    def test_create_target_with_comment(self):
        request = Targets.create_target("foo", hosts=["foo"], comment="bar")

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<comment>bar</comment>"
            b"</create_target>",
        )

    def test_create_target_with_exclude_hosts(self):
        request = Targets.create_target(
            "foo", hosts=["foo", "bar"], exclude_hosts=["bar", "ipsum"]
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo,bar</hosts>"
            b"<exclude_hosts>bar,ipsum</exclude_hosts>"
            b"</create_target>",
        )

    def test_create_target_with_ssh_credential(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], ssh_credential_id="c1"
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b'<ssh_credential id="c1"/>'
            b"</create_target>",
        )

    def test_create_target_with_ssh_credential_port(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], ssh_credential_id="c1", ssh_credential_port=22
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b'<ssh_credential id="c1"><port>22</port></ssh_credential>'
            b"</create_target>",
        )

    def test_create_target_with_smb_credential_id(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], smb_credential_id="c1"
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b'<smb_credential id="c1"/>'
            b"</create_target>",
        )

    def test_create_target_with_esxi_credential_id(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], esxi_credential_id="c1"
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b'<esxi_credential id="c1"/>'
            b"</create_target>",
        )

    def test_create_target_with_snmp_credential_id(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], snmp_credential_id="c1"
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b'<snmp_credential id="c1"/>'
            b"</create_target>",
        )

    def test_create_target_with_alive_tests(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], alive_test=AliveTest.ICMP_PING
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<alive_tests>ICMP Ping</alive_tests>"
            b"</create_target>",
        )

        request = Targets.create_target(
            "foo", hosts=["foo"], alive_test="icmp ping"
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<alive_tests>ICMP Ping</alive_tests>"
            b"</create_target>",
        )

    def test_create_target_invalid_alive_tests(self):
        with self.assertRaises(InvalidArgument):
            Targets.create_target("foo", hosts=["foo"], alive_test="foo")

    def test_create_target_with_allow_simultaneous_ips(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], allow_simultaneous_ips=True
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<allow_simultaneous_ips>1</allow_simultaneous_ips>"
            b"</create_target>",
        )

        request = Targets.create_target(
            "foo", hosts=["foo"], allow_simultaneous_ips=False
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<allow_simultaneous_ips>0</allow_simultaneous_ips>"
            b"</create_target>",
        )

    def test_create_target_with_reverse_lookup_only(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], reverse_lookup_only=True
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<reverse_lookup_only>1</reverse_lookup_only>"
            b"</create_target>",
        )

        request = Targets.create_target(
            "foo", hosts=["foo"], reverse_lookup_only=False
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<reverse_lookup_only>0</reverse_lookup_only>"
            b"</create_target>",
        )

    def test_create_target_with_reverse_lookup_unify(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], reverse_lookup_unify=True
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<reverse_lookup_unify>1</reverse_lookup_unify>"
            b"</create_target>",
        )

        request = Targets.create_target(
            "foo", hosts=["foo"], reverse_lookup_unify=False
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<reverse_lookup_unify>0</reverse_lookup_unify>"
            b"</create_target>",
        )

    def test_create_target_with_port_range(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], port_range="1-65535"
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b"<port_range>1-65535</port_range>"
            b"</create_target>",
        )

    def test_create_target_with_port_list_id(self):
        request = Targets.create_target(
            "foo", hosts=["foo"], port_list_id="pl1"
        )

        self.assertEqual(
            bytes(request),
            b"<create_target>"
            b"<name>foo</name>"
            b"<hosts>foo</hosts>"
            b'<port_list id="pl1"/>'
            b"</create_target>",
        )

    def test_modify_target(self):
        request = Targets.modify_target("t1")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1"/>',
        )

    def test_modify_target_missing_target_id(self):
        with self.assertRaises(RequiredArgument):
            Targets.modify_target(None)

        with self.assertRaises(RequiredArgument):
            Targets.modify_target("")

    def test_modify_target_with_comment(self):
        request = Targets.modify_target("t1", comment="foo")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1"><comment>foo</comment></modify_target>',
        )

    def test_modify_target_with_hosts(self):
        request = Targets.modify_target("t1", hosts=["foo"])

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<hosts>foo</hosts>"
            b"<exclude_hosts></exclude_hosts>"
            b"</modify_target>",
        )

        request = Targets.modify_target("t1", hosts=["foo", "bar"])

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<hosts>foo,bar</hosts>"
            b"<exclude_hosts></exclude_hosts>"
            b"</modify_target>",
        )

    def test_modify_target_with_hosts_and_exclude_hosts(self):
        request = Targets.modify_target(
            "t1", hosts=["foo", "bar"], exclude_hosts=["foo"]
        )

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<hosts>foo,bar</hosts>"
            b"<exclude_hosts>foo</exclude_hosts>"
            b"</modify_target>",
        )

    def test_modify_target_with_name(self):
        request = Targets.modify_target("t1", name="foo")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1"><name>foo</name></modify_target>',
        )

    def test_modify_target_with_exclude_hosts(self):
        request = Targets.modify_target("t1", exclude_hosts=["foo"])

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<exclude_hosts>foo</exclude_hosts>"
            b"</modify_target>",
        )

        request = Targets.modify_target("t1", exclude_hosts=["foo", "bar"])

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<exclude_hosts>foo,bar</exclude_hosts>"
            b"</modify_target>",
        )

    def test_modify_target_with_ssh_credential_id(self):
        request = Targets.modify_target("t1", ssh_credential_id="c1")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b'<ssh_credential id="c1"/>'
            b"</modify_target>",
        )

    def test_modify_target_with_ssh_credential_id_and_port(self):
        request = Targets.modify_target(
            "t1", ssh_credential_id="c1", ssh_credential_port=22
        )

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b'<ssh_credential id="c1"><port>22</port></ssh_credential>'
            b"</modify_target>",
        )

    def test_modify_target_with_smb_credential_id(self):
        request = Targets.modify_target("t1", smb_credential_id="c1")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b'<smb_credential id="c1"/>'
            b"</modify_target>",
        )

    def test_modify_target_with_esxi_credential_id(self):
        request = Targets.modify_target("t1", esxi_credential_id="c1")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b'<esxi_credential id="c1"/>'
            b"</modify_target>",
        )

    def test_modify_target_with_snmp_credential_id(self):
        request = Targets.modify_target("t1", snmp_credential_id="c1")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b'<snmp_credential id="c1"/>'
            b"</modify_target>",
        )

    def test_modify_target_with_alive_tests(self):
        request = Targets.modify_target("t1", alive_test=AliveTest.ICMP_PING)

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<alive_tests>ICMP Ping</alive_tests>"
            b"</modify_target>",
        )

        request = Targets.modify_target("t1", alive_test="icmp ping")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<alive_tests>ICMP Ping</alive_tests>"
            b"</modify_target>",
        )

    def test_modify_target_invalid_alive_tests(self):
        with self.assertRaises(InvalidArgument):
            Targets.modify_target("t1", alive_test="foo")

    def test_modify_target_with_allow_simultaneous_ips(self):
        request = Targets.modify_target("t1", allow_simultaneous_ips=True)

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<allow_simultaneous_ips>1</allow_simultaneous_ips>"
            b"</modify_target>",
        )

        request = Targets.modify_target("t1", allow_simultaneous_ips=False)

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<allow_simultaneous_ips>0</allow_simultaneous_ips>"
            b"</modify_target>",
        )

    def test_modify_target_with_reverse_lookup_only(self):
        request = Targets.modify_target("t1", reverse_lookup_only=True)

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<reverse_lookup_only>1</reverse_lookup_only>"
            b"</modify_target>",
        )

        request = Targets.modify_target("t1", reverse_lookup_only=False)

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<reverse_lookup_only>0</reverse_lookup_only>"
            b"</modify_target>",
        )

    def test_modify_target_with_reverse_lookup_unify(self):
        request = Targets.modify_target("t1", reverse_lookup_unify=True)

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<reverse_lookup_unify>1</reverse_lookup_unify>"
            b"</modify_target>",
        )

        request = Targets.modify_target("t1", reverse_lookup_unify=False)

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b"<reverse_lookup_unify>0</reverse_lookup_unify>"
            b"</modify_target>",
        )

    def test_modify_target_with_port_list_id(self):
        request = Targets.modify_target("t1", port_list_id="pl1")

        self.assertEqual(
            bytes(request),
            b'<modify_target target_id="t1">'
            b'<port_list id="pl1"/>'
            b"</modify_target>",
        )

    def test_clone_target(self):
        request = Targets.clone_target("t1")

        self.assertEqual(
            bytes(request),
            b"<create_target><copy>t1</copy></create_target>",
        )

    def test_clone_target_missing_target_id(self):
        with self.assertRaises(RequiredArgument):
            Targets.clone_target(None)

        with self.assertRaises(RequiredArgument):
            Targets.clone_target("")

    def test_delete_target(self):
        request = Targets.delete_target("t1")

        self.assertEqual(
            bytes(request),
            b'<delete_target target_id="t1" ultimate="0"/>',
        )

    def test_delete_ultimate(self):
        request = Targets.delete_target("t1", ultimate=True)

        self.assertEqual(
            bytes(request),
            b'<delete_target target_id="t1" ultimate="1"/>',
        )

        request = Targets.delete_target("t1", ultimate=False)

        self.assertEqual(
            bytes(request),
            b'<delete_target target_id="t1" ultimate="0"/>',
        )

    def test_delete_target_missing_target_id(self):
        with self.assertRaises(RequiredArgument):
            Targets.delete_target(None)

        with self.assertRaises(RequiredArgument):
            Targets.delete_target("")

    def test_get_target(self):
        request = Targets.get_target("t1")

        self.assertEqual(
            bytes(request),
            b'<get_targets target_id="t1"/>',
        )

    def test_get_target_with_tasks(self):
        request = Targets.get_target("t1", tasks=True)

        self.assertEqual(
            bytes(request),
            b'<get_targets target_id="t1" tasks="1"/>',
        )

        request = Targets.get_target("t1", tasks=False)

        self.assertEqual(
            bytes(request),
            b'<get_targets target_id="t1" tasks="0"/>',
        )

    def test_get_target_missing_target_id(self):
        with self.assertRaises(RequiredArgument):
            Targets.get_target(None)

        with self.assertRaises(RequiredArgument):
            Targets.get_target("")

    def test_get_targets(self):
        request = Targets.get_targets()

        self.assertEqual(
            bytes(request),
            b"<get_targets/>",
        )

    def test_get_targets_with_filter_string(self):
        request = Targets.get_targets(filter_string="foo=bar")

        self.assertEqual(
            bytes(request),
            b'<get_targets filter="foo=bar"/>',
        )

    def test_get_targets_with_filter_id(self):
        request = Targets.get_targets(filter_id="f1")

        self.assertEqual(
            bytes(request),
            b'<get_targets filt_id="f1"/>',
        )

    def test_get_targets_with_trash(self):
        request = Targets.get_targets(trash=True)

        self.assertEqual(
            bytes(request),
            b'<get_targets trash="1"/>',
        )

        request = Targets.get_targets(trash=False)

        self.assertEqual(
            bytes(request),
            b'<get_targets trash="0"/>',
        )

    def test_get_targets_with_tasks(self):
        request = Targets.get_targets(tasks=True)

        self.assertEqual(
            bytes(request),
            b'<get_targets tasks="1"/>',
        )

        request = Targets.get_targets(tasks=False)

        self.assertEqual(
            bytes(request),
            b'<get_targets tasks="0"/>',
        )



# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

import unittest

from gvm.protocols.gmp.requests.v226 import FilterType


class FilterTypeTestsCase(unittest.TestCase):
    def test_filter_type_all_secinfo(self):
        self.assertEqual(FilterType.ALL_SECINFO.value, "secinfo")

    def test_filter_type_alert(self):
        self.assertEqual(FilterType.ALERT.value, "alert")

    def test_filter_type_audit_report(self):
        self.assertEqual(FilterType.AUDIT_REPORT.value, "audit_report")

    def test_filter_type_asset(self):
        self.assertEqual(FilterType.ASSET.value, "asset")

    def test_filter_type_credential(self):
        self.assertEqual(FilterType.CREDENTIAL.value, "credential")

    def test_filter_type_filter(self):
        self.assertEqual(FilterType.FILTER.value, "filter")

    def test_filter_type_group(self):
        self.assertEqual(FilterType.GROUP.value, "group")

    def test_filter_type_host(self):
        self.assertEqual(FilterType.HOST.value, "host")

    def test_filter_type_note(self):
        self.assertEqual(FilterType.NOTE.value, "note")

    def test_filter_type_operating_system(self):
        self.assertEqual(FilterType.OPERATING_SYSTEM.value, "os")

    def test_filter_type_override(self):
        self.assertEqual(FilterType.OVERRIDE.value, "override")

    def test_filter_type_permission(self):
        self.assertEqual(FilterType.PERMISSION.value, "permission")

    def test_filter_type_port_list(self):
        self.assertEqual(FilterType.PORT_LIST.value, "port_list")

    def test_filter_type_report(self):
        self.assertEqual(FilterType.REPORT.value, "report")

    def test_filter_type_report_config(self):
        self.assertEqual(FilterType.REPORT_CONFIG.value, "report_config")

    def test_filter_type_report_format(self):
        self.assertEqual(FilterType.REPORT_FORMAT.value, "report_format")

    def test_filter_type_result(self):
        self.assertEqual(FilterType.RESULT.value, "result")

    def test_filter_type_role(self):
        self.assertEqual(FilterType.ROLE.value, "role")

    def test_filter_type_scan_config(self):
        self.assertEqual(FilterType.SCAN_CONFIG.value, "config")

    def test_filter_type_schedule(self):
        self.assertEqual(FilterType.SCHEDULE.value, "schedule")

    def test_filter_type_tag(self):
        self.assertEqual(FilterType.TAG.value, "tag")

    def test_filter_type_target(self):
        self.assertEqual(FilterType.TARGET.value, "target")

    def test_filter_type_task(self):
        self.assertEqual(FilterType.TASK.value, "task")

    def test_filter_type_ticket(self):
        self.assertEqual(FilterType.TICKET.value, "ticket")

    def test_filter_type_tls_certificate(self):
        self.assertEqual(FilterType.TLS_CERTIFICATE.value, "tls_certificate")

    def test_filter_type_user(self):
        self.assertEqual(FilterType.USER.value, "user")

    def test_filter_type_vulnerability(self):
        self.assertEqual(FilterType.VULNERABILITY.value, "vuln")

    def test_filter_type_from_string_vuln(self):
        self.assertEqual(
            FilterType.from_string("vuln"), FilterType.VULNERABILITY
        )

    def test_filter_type_from_string_os(self):
        self.assertEqual(
            FilterType.from_string("os"), FilterType.OPERATING_SYSTEM
        )

    def test_filter_type_from_string_config(self):
        self.assertEqual(
            FilterType.from_string("config"), FilterType.SCAN_CONFIG
        )

    def test_filter_type_from_string_secinfo(self):
        self.assertEqual(
            FilterType.from_string("secinfo"), FilterType.ALL_SECINFO
        )



# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from gvm.errors import RequiredArgument


class GmpCloneAlertTestMixin:
    def test_clone(self):
        self.gmp.clone_alert("a1")

        self.connection.send.has_been_called_with(
            b"<create_alert><copy>a1</copy></create_alert>"
        )

    def test_missing_id(self):
        with self.assertRaises(RequiredArgument):
            self.gmp.clone_alert("")

        with self.assertRaises(RequiredArgument):
            self.gmp.clone_alert(None)
